@@ -86,7 +86,7 @@
 #define KIOCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOCORE_NO_DEPRECATED
-#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
+#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55c00
 #endif
 #ifdef KIOCORE_NO_DEPRECATED_WARNINGS
 #  define KIOCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOCORE_DEPRECATED_WARNINGS_SINCE KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55700
+#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55c00
 #  endif
 #endif
 
@@ -277,6 +277,24 @@
 #else
 #  define KIOCORE_DEPRECATED_VERSION_5_86(text)
 #endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55800
+#  define KIOCORE_DEPRECATED_VERSION_5_88(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_88(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55a00
+#  define KIOCORE_DEPRECATED_VERSION_5_90(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_90(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55b00
+#  define KIOCORE_DEPRECATED_VERSION_5_91(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_91(text)
+#endif
 #define KIOCORE_DEPRECATED_VERSION_3(minor, text)      KIOCORE_DEPRECATED_VERSION_3_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_4(minor, text)      KIOCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_5(minor, text)      KIOCORE_DEPRECATED_VERSION_5_##minor(text)
@@ -344,7 +362,7 @@
 #define KIOCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOCORE_NO_DEPRECATED
-#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
+#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55c00
 #endif
 #ifdef KIOCORE_NO_DEPRECATED_WARNINGS
 #  define KIOCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -354,7 +372,7 @@
 #  ifdef KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOCORE_DEPRECATED_WARNINGS_SINCE KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55700
+#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55c00
 #  endif
 #endif
 
@@ -535,6 +553,24 @@
 #else
 #  define KIOCORE_DEPRECATED_VERSION_5_86(text)
 #endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55800
+#  define KIOCORE_DEPRECATED_VERSION_5_88(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_88(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55a00
+#  define KIOCORE_DEPRECATED_VERSION_5_90(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_90(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55b00
+#  define KIOCORE_DEPRECATED_VERSION_5_91(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_91(text)
+#endif
 #define KIOCORE_DEPRECATED_VERSION_3(minor, text)      KIOCORE_DEPRECATED_VERSION_3_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_4(minor, text)      KIOCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_5(minor, text)      KIOCORE_DEPRECATED_VERSION_5_##minor(text)
